@@ -10,9 +10,7 @@
 #define GENERAL_BSPARTI_H
 
 #include <stdio.h>
-
-struct decomp_TREE;
-struct leaf_node;
+#include "intercomm.h"
 
 typedef struct decomp_birreg {
   int nDims;
@@ -20,13 +18,7 @@ typedef struct decomp_birreg {
   struct decomp_TREE *root;
 } decomp_Birreg;
 
-typedef struct decomp_TREE {
-  int nDims;
-  int num_of_partitions;
-  struct decomp_TREE* children;
-  int *keys;
-  struct leaf_node *block_info;
-} Decomp_TREE;
+typedef struct decomp_TREE Decomp_TREE;
 
 typedef struct leaf_node {
   int proc;          /*which processor owns */
