@@ -438,6 +438,23 @@ void IC_EndPoint::importArray(const doubleArray& a, int& status) {
   status=IC_OK;
 }
 
+
+
+int IC_Create_bdecomp_desc(intArray& a) {
+  IC_Desc* desc = getPartiDescriptor(a);
+  return pinsert((void*)desc);
+}
+
+int IC_Create_bdecomp_desc(floatArray& a) {
+  IC_Desc* desc = getPartiDescriptor(a);
+  return pinsert((void*)desc);
+}
+
+int IC_Create_bdecomp_desc(doubleArray& a) {
+  IC_Desc* desc = getPartiDescriptor(a);
+  return pinsert((void*)desc);
+}
+
 #endif
 
 #ifdef FORTRAN90
