@@ -5,13 +5,13 @@
 #include <errno.h>
 #include <iostream>
 #include <iomanip>
-#include <fstream.h>
+#include <fstream>
 #include <math.h>
 #include <sys/utsname.h>
 #include <stdio.h>
 #include <iostream>
-#include <fstream.h>
-#include <string.h>
+#include <fstream>
+#include <string>
 #include <sys/time.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -49,6 +49,8 @@ extern long gethostid(void);
 #include "InterComm.h"
 #include "IC_support.h"
 
+using namespace std;
+
 #ifndef HZ
 #  include <sys/param.h>
 #endif
